create_group_ex

Function create_group_ex 

pub(crate) async fn create_group_ex(
    context: &Context,
    sync: Sync,
    grpid: String,
    name: &str,
) -> Result<ChatId>
Creates a group chat.

  • sync - Whether a multi-device synchronization message should be sent. Ignored for unencrypted chats currently.
  • grpid - Group ID. Iff nonempty, the chat is encrypted (with key-contacts).
  • name - Chat name.

NB: Unencrypted chats with similar names and the same members are merged on other devices, but usually users don’t create such chats and look up the existing one instead, so chat split on the first device is acceptable.