pub async fn resend_msgs(context: &Context, msg_ids: &[MsgId]) -> Result<()>
Resends given messages to members of the corresponding chats.
This is primarily intended to make existing webxdcs available to new chat members.