resend_msgs_ex

Function resend_msgs_ex 

pub(crate) async fn resend_msgs_ex(
    context: &Context,
    msg_ids: &[MsgId],
    to_fingerprint: Option<Fingerprint>,
) -> Result<()>
Resends given messages to a contact with fingerprint to_fingerprint or, if it’s None, to members of the corresponding chats.

NB: Actually to_fingerprint is only passed for OutBroadcast chats when a new member is added. Regarding webxdcs: It is not trivial to resend only the own status updates, and it is not trivial to resend them only to the newly-joined member, so that for now, resend_last_msgs does not automatically resend webxdcs at all.