pub(crate) async fn remove_from_chat_contacts_table_without_trace(
context: &Context,
chat_id: ChatId,
contact_id: ContactId,
) -> Result<bool>Expand description
Removes a contact from the chat without leaving a trace in the db. Returns whether the contact was removed, even if it was a past contact. If so, a removal message should be sent if the removal is issued by this device.
Note that if we call this function, and then receive a message from another device that doesn’t know that this this member was removed then the group membership algorithm will wrongly re-add this member.